exceptiontools.ExtraSpannerError
================================

.. abjad-lineage:: abjad.tools.exceptiontools.ExtraSpannerError.ExtraSpannerError

.. autoclass:: abjad.tools.exceptiontools.ExtraSpannerError.ExtraSpannerError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.ExtraSpannerError.ExtraSpannerError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraSpannerError.ExtraSpannerError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraSpannerError.ExtraSpannerError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraSpannerError.ExtraSpannerError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraSpannerError.ExtraSpannerError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraSpannerError.ExtraSpannerError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraSpannerError.ExtraSpannerError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraSpannerError.ExtraSpannerError.__unicode__
   :noindex:
